Hourly meteorological data for LGA, JFK and EWR for the month of January 2023.
This is a subset of the weather data frame from nycflights23.
early_january_2023_weatherA data frame of 360 rows representing hourly measurements and 15 variables
Weather station. Named origin to facilitate merging with
nycflights23::flights data.
Time of recording.
Temperature and dewpoint in F.
Relative humidity.
Wind direction (in degrees), speed and gust speed (in mph).
Precipitation, in inches.
Sea level pressure in millibars.
Visibility in miles.
Date and hour of the recording as a POSIXct date.
nycflights23::weather.